var system = require("../../../system");
var settings = require("../../../../config/settings");
const AppServiceBase = require("../../app.base");

const aliyunClient = system.getObject("util.aliyunClient");

class UtilsFqAliyunSve extends AppServiceBase {
  constructor() {
    super();
    this.logCtl = system.getObject("service.common.oplogSve");
    this.pushlogSve = system.getObject("service.common.pushlogSve");
  }
  async pushOldNeedBusiness(pobj) {//推送旧的需求商机
    return system.getResultSuccess();
  }
  async pushOrderBusiness(pobj) {//推送订单商机
    var orderInfo = pobj.actionBody.order_info;
    if (!orderInfo) {
      return "";
    }
    if (orderInfo.orderStatus < 2) {
      return "";
    }
    var orderContact = pobj.actionBody.order_contact;
    var productInfo = pobj.actionBody.product_info;
    if (!pobj.interface_params) {
      return "";
    }
    var interface_params_info = JSON.parse(pobj.interface_params);
    if (!interface_params_info || !interface_params_info.opUrl || !interface_params_info.key || !interface_params_info.secret) {
      return "";
    }
    var params = {
      idempotentId: orderInfo.orderNo,// 是 业务 ID
      idempotentSource: productInfo.service_business_code,// 是 业务来源（ic_jdyun、ic_ali）
      idempotentSourceName: productInfo.service_business_code,// 是 京东云应用、阿里云应用
      city: "",// 否 所属城市
      phone: orderContact.mobile,// 是 手机号
      userId: orderInfo.channelUserId,// 否 用户 ID
      companyName: "",// 否 公司名称
      orderPrice: orderInfo.totalSum,// 是 订单金额
      productId: productInfo.price_item.service_code,// 是 产品 ID
      productQuantity: orderInfo.quantity,// 是 产品数量
    };
    var result = this.opAliyunClientPost(pobj, "pushOrderBusiness", interface_params_info.opUrl, interface_params_info.key, interface_params_info.secret, params);
  }

  async pushAliBusiness2Fq(pobj) {//推送阿里工商需求商机
    if (!pobj.interface_params) {
      return "";
    }
    var interface_params_info = JSON.parse(pobj.interface_params);
    if (!interface_params_info || !interface_params_info.opUrl || !interface_params_info.key || !interface_params_info.secret) {
      return "";
    }
    var result = this.opAliyunClientPost(pobj, "pushAliIcNeedBusiness", interface_params_info.opUrl, interface_params_info.key, interface_params_info.secret, pobj.actionBody);
  }

  async opAliyunClientPost(pobj, methodName, url, key, secret, params) {
    try {
      var rc = system.getObject("util.aliyunClient");
      var rtn = await rc.post(url, key, secret, params);
      this.logCtl.info({
        appid: pobj.appInfo ? pobj.appInfo.uapp_id || "" : "",
        appkey: pobj.appInfo ? pobj.appInfo.uapp_key || "" : "",
        requestId: pobj.requestId || "",
        op: "center-channel/app/base/service/impl/utilsSve/opAliyunClientPost.js/" + methodName,
        content: "请求地址：" + url + "，参数：" + JSON.stringify(params) + "，返回结果：" + JSON.stringify(rtn),
        optitle: "推送商机->opAliyunClientPost",
      });
      if (rtn.code != 200 && rtn.success != true) {
        this.pushlogSve.createDb({
          appid: pobj.appInfo.uapp_id,
          appkey: pobj.appInfo.uapp_key,
          requestId: pobj.requestId || "",
          op: "推送的接口信息：" + JSON.stringify(pobj.interface_info),
          content: "推送的参数信息：" + JSON.stringify(pobj),
          resultInfo: JSON.stringify(rtn),
          returnType: '0',
          opTitle: pobj.opType + "推送操作出错->opAliyunClientPost"
        });
        return system.getResult(null, "推送失败，失败原因：" + rtn.errorMsg + "，selfrequestId=" + pobj.requestId + "，requestId=" + rtn.requestId);
      }
      this.pushlogSve.createDb({
        appid: pobj.appInfo.uapp_id,
        appkey: pobj.appInfo.uapp_key,
        op: "推送的接口信息：" + JSON.stringify(pobj.interface_info),
        content: "推送的参数信息：" + JSON.stringify(pobj),
        resultInfo: JSON.stringify(rtn),
        returnType: '1',
        opTitle: pobj.opType + "数据推送成功->opAliyunClientPost"
      });
      return system.getResultSuccess(null, "推送成功");
    } catch (e) {
      this.pushlogSve.createDb({
        appid: pobj.appInfo.uapp_id,
        appkey: pobj.appInfo.uapp_key,
        op: "推送的接口信息：" + JSON.stringify(pobj.interface_info),
        content: "推送的参数信息：" + JSON.stringify(pobj),
        resultInfo: "error：" + e.stack,
        returnType: '0',
        opTitle: pobj.opType + "推送操作异常->opAliyunClientPost"
      });
      //日志记录
      this.logCtl.error({
        appid: pobj.appInfo ? pobj.appInfo.uapp_id || "" : "",
        appkey: pobj.appInfo ? pobj.appInfo.uapp_key || "" : "",
        requestId: pobj.requestId || "",
        op: "center-channel/app/base/service/impl/utilsSve/opAliyunClientPost.js/" + methodName,
        content: "error：" + e.stack,
        // clientIp: pobj.clientIp,
        optitle: pobj.opType + "推送操作异常->opAliyunClientPost",
      });
      return system.getResult(null, "推送error");
    }
  }
}
module.exports = UtilsFqAliyunSve;
